git: 9871ae6aa91f - main - Track kern.ipc.somaxconn -> kern.ipc.soacceptqueue rename

From: Ed Maste <emaste_at_FreeBSD.org>
Date: Tue, 11 Oct 2022 16:48:05 UTC
The branch main has been updated by emaste:

URL: https://cgit.FreeBSD.org/src/commit/?id=9871ae6aa91f82a6932be7fcfa1023b077be8e2e

commit 9871ae6aa91f82a6932be7fcfa1023b077be8e2e
Author:     Jose Luis Duran <jlduran@gmail.com>
AuthorDate: 2022-10-11 16:39:26 +0000
Commit:     Ed Maste <emaste@FreeBSD.org>
CommitDate: 2022-10-11 16:46:46 +0000

    Track kern.ipc.somaxconn -> kern.ipc.soacceptqueue rename
    
    Fixes:          2bdf61ca29d0 ("Hide the unfortunate named sysctl...")
    MFC after:      3 days
---
 release/tools/gce.conf                                   | 2 +-
 share/man/man7/tuning.7                                  | 4 ++--
 tools/regression/sockets/listen_backlog/listen_backlog.c | 8 ++++----
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/release/tools/gce.conf b/release/tools/gce.conf
index 74e7455cb9dd..253140bb4ca8 100644
--- a/release/tools/gce.conf
+++ b/release/tools/gce.conf
@@ -86,7 +86,7 @@ net.inet.icmp.drop_redirect=1
 net.inet.ip.redirect=0
 net.inet.tcp.blackhole=2
 net.inet.udp.blackhole=1
-kern.ipc.somaxconn=1024
+kern.ipc.ssoacceptqueue=1024
 debug.trace_on_panic=1
 debug.debugger_on_panic=0
 EOF
diff --git a/share/man/man7/tuning.7 b/share/man/man7/tuning.7
index 63e09ecce098..6cfb0dd15bc4 100644
--- a/share/man/man7/tuning.7
+++ b/share/man/man7/tuning.7
@@ -24,7 +24,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd April 16, 2020
+.Dd October 11, 2022
 .Dt TUNING 7
 .Os
 .Sh NAME
@@ -482,7 +482,7 @@ By default
 is set at the maximum allowable port number.
 .Pp
 The
-.Va kern.ipc.somaxconn
+.Va kern.ipc.soacceptqueue
 sysctl limits the size of the listen queue for accepting new TCP connections.
 The default value of 128 is typically too low for robust handling of new
 connections in a heavily loaded web server environment.
diff --git a/tools/regression/sockets/listen_backlog/listen_backlog.c b/tools/regression/sockets/listen_backlog/listen_backlog.c
index 2276393ee6f1..9d156c36aa60 100644
--- a/tools/regression/sockets/listen_backlog/listen_backlog.c
+++ b/tools/regression/sockets/listen_backlog/listen_backlog.c
@@ -44,7 +44,7 @@
  *
  * Future things to test:
  *
  * - That if we change the value of kern.ipc.somaxconn, the limits really
  *   do change.
  *
  * - That limits are, approximately, enforced and implemented.
@@ -55,7 +55,7 @@
  */
 
 /*
  * We retrieve kern.ipc.somaxconn before running the tests in order to use a
  * run-time set value of SOMAXCONN, rather than compile-time set.  We assume
  * that no other process will be simultaneously frobbing it, and these tests
  * may fail if that assumption is not held.
@@ -371,9 +371,9 @@ main(void)
 	size_t len;
 
 	len = sizeof(somaxconn);
-	if (sysctlbyname("kern.ipc.somaxconn", &somaxconn, &len, NULL, 0)
+	if (sysctlbyname("kern.ipc.soacceptqueue", &somaxconn, &len, NULL, 0)
 	    < 0)
-		err(-1, "sysctlbyname(kern.ipc.somaxconn)");
+		err(-1, "sysctlbyname(kern.ipc.soacceptqueue)");
 
 	test_defaults();
 	test_listen_update();
@@ -44,7 +44,7 @@
  * Future things to test:
  *
- * - That if we change the value of kern.ipc.somaxconn, the limits really
+ * - That if we change the value of kern.ipc.soacceptqueue, the limits really
  *   do change.
  *
@@ -55,7 +55,7 @@
 
 /*
- * We retrieve kern.ipc.somaxconn before running the tests in order to use a
+ * We retrieve kern.ipc.soacceptqueue before running the tests in order to use a
  * run-time set value of SOMAXCONN, rather than compile-time set.  We assume
  * that no other process will be simultaneously frobbing it, and these tests